import { ResolvePluginInstance, Resolver } from 'webpack';
/**Replaces modules in the configured `from` directory with their respective counterparts in the configured `to` directory (if present).
 * `mainFiles` and `extensions` provided to webpack's resolve options are taken into account; but any import which webpack supports may be replaced, not only modules (images and stylesheets for example).
 * @example
 * Given the following directory structure:
 * ```
 * src/
 * ├ foo/
 * │ ├ index.ts
 * │ └ bar.ts
 * └ index.ts
 * acme/
 * └ foo/
 *   └ index.ts
 * ```
 * And the options:
 * ```js
 * {
 *   from: path.resolve("./src")
 *   to: path.resolve("./acme")
 * }
 * ```
 * When the following code is added to `src/index.ts`:
 * ```ts
 * const foo = await import("./foo");
 * const bar = await import("./foo/bar");
 * ```
 * Then `foo` is replaced with `acme/foo/index.ts` and `bar` remains as `src/foo/bar.ts`.
 */
export declare class ReplaceResolvePlugin implements ResolvePluginInstance {
	readonly options: OverrideResolverPluginOptions;
	constructor(options: OverrideResolverPluginOptions);
	/**@inheritdoc */
	apply(resolver: Resolver): void;
}
export interface OverrideResolverPluginOptions {
	/**Absolute path to the root directory of files which are candidates for replacement. */
	from: string;
	/**Absolute path to the root directory of files which are replacements for their relative equivalents under `from`.*/
	to: string;
}
export {
	ReplaceResolvePlugin as default,
};